<?php

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

function mediabox_config_theme() {
	$config = array(
		'minHeight' => false,
		'minWidth' => false
	);

	return $config;
}
